      SUBROUTINE POTENL(ICNTRL, MXLMB, MPOTL, LAM, R, P, ITYP)

c  this version modified to use vecevalh2co function to evaluate 
c     Szalewicz and Jankowski's h2co potential.  Not generally
c     applicable to other problems.  This is good only for
c     itype = 3 and 23, not for IOS calculations.

c  mods 6/29/99 gcm

c  Also modified to add POTL input variable distscal (default 1.0),
c  which will be multiplied into R before each call to potential 
c  evaluation routine.  This allows smooth scaling of the length
c  of the potential, to adjust B constant and so on.

c  mods 1/27/2000 gcm

c  Also modified 3/25/00 to add input variable escal (default 1.0),
c  which allows scaling the potential globally in a manner similar to 
c  distscal.


C
C     -----------------------------------------------------------------
C    * MOLSCAT GENERAL POTENL ROUTINE; DESCRIPTION OF FUNCTIONS:
C     -----------------------------------------------------------------
C     VERSION 14 IMPLEMENTS THREE OPTIONS FOR DESCRIBING THE POT'L
C       1. POT'L EXPANDED IN ANGULAR FUNCTIONS - SYMMETRIES DESCRIBED
C          BY MXLAM,LAMBDA INPUT, RADIAL COEFFS DESCRIBED BY INPUT
C          POWERS AND EXPONENTIALS *OR* VSTAR MECHANISM.
C          THIS IS THE ORIGINAL MOLSCAT OPTION.
C          MXLAM.GT.0 MUST BE INPUT AND LVRTP MUST BE .FALSE. (DEFAULT)
C       2. POT'L EXPANDED IN ANGULAR FUNCTIONS - PROJECTED VIA VRTP
C          MECHANISM.  SYMMETRIES MAY BE DESCRIBED *EITHER* BY
C          A.) SYMMETRY DESCRIPTIONS INPUT VIA LAMBDA ARRAY
C              MXLAM.GT.0 AND LVRTP=.TRUE. *MUST* BE INPUT
C          B.) SYMMETRY DESCRIPTIONS GENERATED FROM LMAX (MMAX)
C              MXLAM.LE.0 (DEFAULT) AND  LMAX.GE.0 MUST BE INPUT
C          IF BOTH ARE SPECIFIED (MXLAM.GT.0.AND.LMAX.GE.0) LMAX IS
C              IGNORED, I.E., CASE (2-A) TAKES PRECEDENCE
C          ALLOWED ONLY FOR NON-IOS CASES (ITYPE.LT.100)
C       3. POT'L IS NOT EXPANDED IN ANGULAR FUNCTIONS (SUITABLE FOR
C          IOS CALCULATIONS ONLY) AND IS OBTAINED VIA THE VRTP MECHANISM
C          MXLAM.LE.0 MUST BE SPECIFIED (AND ITYPE.GT.100 IN &BASIS)
C
C     -----------------------------------------------------------------
C    * NOTES ON HISTORY OF ROUTINE:
C     -----------------------------------------------------------------
C
C    *INTRODUCES XPT(MXPT,MXDIM), XWT(MXPT,MXDIM), INX(MXDIM),*
C    *    NPTS(MXDIM); NPTS IS IN NAMELIST /BASIN/            *
C    *    TO ALLOW GENERAL, MULTI-DIMENSIONAL PROJECTIONS     *
C    **********************************************************
C     CORRECTIONS 19 OCT 95 AFFECTING PROJECTION OF ITYPE=3 (SG)
C     PROJECTION FOR ITYPE=3 ADDED 20 JUL 94
C     CODE FOR ITYPE=4 ADDED BY SG 30 JUN 94 (FOLLOWING TRP CODE)
C              ITYPE=9 INTERFACE ADDED BY JMH 15 AUG 94
C     PREVIOUS REVISION DATES 1 FEB 1994 (SG); 3 JAN 1994 (JMH).
C     -----------------------------------------------------------------
C
c     NTOT added to this list 6/28/99 gcm
c     distscal, escal also added
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SAVE LVRTP,ITSAVE,NTERM,NPOWER,A,E,NPT,NPS,NPTS,XPT,XWT,
     1    IXFAC,NDIM,NTOT,distscal,escal
C
C     -----------------------------------------------------------------
C    * NOTES FOR PROGRAMS OTHER THAN MOLSCAT (STORAGE CONSIDERATIONS):
C     -----------------------------------------------------------------
C     THE X() ARRAY CAN BE DEFINED INTERNALLY OR, IF THIS ROUTINE
C       IS USED WITH THE MOLSCAT CODE, IT IS TAKEN FROM THE
C       /MEMORY/...,X()  STORAGE MECHANISM IN MOLSCAT.
C     THIS DECK SHOULD BE MODIFIED ACCORDINGLY IN THE STATEMENTS BELOW
C       AND THE STATEMENTS WHICH FOLLOW STATEMENT NUMBER 2000
C     -----------------------------------------------------------------
C     ----- NEXT TWO STATEMENTS ARE USED FOR INTERNAL X() STORAGE -----
C     ----- ALSO, "X" MUST BE ADDED TO THE "SAVE" STATEMENT ABOVE -----
C     PARAMETER (MXX=30000)
C     DIMENSION X(MXX)
C     ----- NEXT TWO STATEMENTS ARE FOR MOLSCAT /MEMORY/ MECHANISM-----
      DIMENSION X(1)
      COMMON /MEMORY/ MX,IXNEXT,NIPR,IVLFL,X

c  next line added for h2co common block gcm
      include 'vecstorh2co.f'
C
C     -----------------------------------------------------------------
C    * SPECIFICATION STATEMENTS:
C     -----------------------------------------------------------------
C     MXDIM IS MAX NUMBER OF DIMENSIONS FOR PROJECTION
C     MXPT LIMITS POINTS PER DIMENSION FOR PROJECTION
C     MXHERM LIMITS HERMITE POLYNOMIALS FOR VIBRATIONAL PROJECTION
      PARAMETER (MXPT=96, MXDIM=3, MXHERM=20)
C     DIMENSIONS FOR LAMBDA AND POWER/EXPONENTIAL TERMS
      PARAMETER (MXL=360, IXMX=200, IEXMX=200, NPXMX=20)
      INTEGER CFLAG
      LOGICAL QOUT,LVRTP, XLAM,LCALC
      CHARACTER*8 QNAME(10), QTYPE(10)
C     CHARACTER*6 PNAMES
C     DIMENSION PNAMES(25),LOCN(25),INDX(25)
      DIMENSION P(MXLMB), LAM(MXLMB)
      DIMENSION NTERM(MXL),NPOWER(IXMX),NPUNI(NPXMX),LAMBDA(MXL)
      DIMENSION A(IXMX), E(IEXMX)
      DIMENSION H(MXHERM)
      DIMENSION XPT(MXPT,MXDIM),XWT(MXPT,MXDIM),INX(MXDIM),NPTS(MXDIM)
      EQUIVALENCE (NPT,NPTS(1)), (NPS,NPTS(2))

c     vector to hold temporary arrays of potential values
      dimension tempot(mxpt*mxpt*mxpt)
C
      EQUIVALENCE (MXLAM,MXSYM),(LMAX,L1MAX)
      COMMON/NPOT/NPTL
      COMMON/ANGLES/COSANG(7),FACTOR,IHOMO,ICNSYM,IHOMO2,ICNSY2
C
C     -----------------------------------------------------------------
C    * NAMELIST SPECIFICATION (AND DESCRIPTION OF PARAMETERS):
C     -----------------------------------------------------------------
c   distscal and escal added gcm
      NAMELIST/POTL/ RM,EPSIL,MXLAM,MXSYM,LAMBDA,NPOTL,NTERM,
     1   A,NPOWER,E,CFLAG,LVRTP,NPT,NPS,
     2   IHOMO,ICNSYM,LMAX,L1MAX,L2MAX,MMAX,IVMIN,IVMAX,
     3   NPTS,IHOMO2,ICNSY2,distscal,escal
C     DATA PNAMES/'RM','EPSIL','MXLAM','MXSYM','LAMBDA','NPOTL','NTERM',
C    1   'A','NPOWER','E','CFLAG','LVRTP','NPT','NPS',
C    2   'IHOMO','ICNSYM','LMAX','L1MAX','L2MAX','MMAX','IVMIN','IVMAX',
C    3   'NPTS','IHOMO2','ICNSY2'/
C     DATA INDX/25*0/
C
C     RM     - LENGTH SCALING FACTOR; VALUE IN ANGSTROMS
C     EPSIL  - ENERGY SCALING FACTOR; VALUE IN WAVENUMBERS (1/CM)
C     MXLAM  - NUMBER OF POTENTIAL TERMS RETURNED
C     MXSYM  - A SYNONYM FOR MXLAM, RETAINED FOR COMPATIBILITY
C     LAMBDA - SYMMETRY INDICES FOR POTENTIAL
C     NPOTL  - NO LONGER A RELEVANT INPUT PARAMETER
C     -------- BELOW DESCRIBE TERMS AS EXPONENETIALS/INVERSE POWERS
C     NTERM  - ARRAY: NTERM(I) IS NUMBER OF TERMS CONTRIBUTING TO P(I)
C              NTERM(I) .LT. 0 CALLS VINIT/VSTAR FOR POTENTIAL TERM I
C     A      - ARRAY OF PRE-EXPONENTIAL (OR PRE-POWER) FACTORS
C              FIRST NTERM(1) ELEMENTS REFER TO P(1),
C              NEXT  NTERM(2) ELEMENTS REFER TO P(2) ETC.
C     NPOWER - ARRAY OF POWERS FOR POTENTIAL TERMS
C              NPOWER HAS SAME ORDERING AS A
C              NPOWER(J) .EQ. 0 INDICATES EXPONENTIAL
C     E      - ARRAY OF EXPONENTS: EACH ELEMENT OF THIS ARRAY
C              CORRESPONDS TO A ZERO IN THE NPOWER ARRAY,
C              IE E(1) CORRESPONDS TO FIRST ZERO, E(2) TO SECOND ETC.
C     CFLAG  - FLAG FOR SCALING POTENTIAL FOR ITYPE = 5 OR 6:
C              SET CFLAG=1 IF INPUT A COEFFICIENTS ARE FOR AN
C              EXPANSION IN C_LM INSTEAD OF Y_LM
C     -------- BELOW ARE FOR POTENTIALS PROJECTION VIA VRTP MECHANISM
C     LVRTP  - LOGICAL FLAG FOR NON-EXPANDED POTENTIAL:
C              MXLAM.LE.0 (DEFAULT) FORCES LVRTP=.TRUE.
C     NPTS   - NUMBERS OF GAUSS POINTS FOR PROJECTING POTENTIAL
C     NPT    - EQUIVALENT TO NPTS(1)
C     NPS    - EQUIVALENT TO NPTS(2)
C     IHOMO  - 2 IF POTENTIAL IS SYMMETRIC ABOUT THETA=90, 1 OTHERWISE
C     ICNSYM - ORDER OF ROTATIONAL SYMMETRY ABOUT PRINCIPAL AXIS
C              ALSO USED FOR 2ND MOLECULE (I.E., IHOMO2) IN ITYPE=3
C              (NOTE: IHOMO & ICNSYM ARE NORMALLY COMPUTED
C               AUTOMATICALLY OR SET BY THE SUPPLIED VRTP ROUTINE)
C     -------- BELOW ARE FOR AUTOMATIC GENERATION OF LAMBDA ARRAY;
C              ONLY FOR PROJECTED  POT'LS (LVRTP = TRUE) IF LMAX.GE.0
C     LMAX   - INCLUDE ALL TERMS FROM 0 TO LMAX IN STEPS OF IHOMO
C     L1MAX  - MAX L1 VALUE FOR MOLECULE-1 (ITYPE=3)
C     L2MAX  - MAX L2 VALUE FOR MOLECULE-2 (ITYPE=3)
C     MMAX   - FOR ITYPE = 5 OR 6, EXCLUDE TERMS WITH M.GT.MMAX
C     IVMIN, IVMAX - FOR ITYPE = 2, V LOOPS FROM IVMIN TO IVMAX
C
      DATA QTYPE/'LAMBDA =','ABS(MU)=','   MU = ','   L1 = ',
     1           '   L2 = ','    L = ','    V = ','V-PRIME=',
     2           '   J =  ','J-PRIME='/
C
C     STATEMENT FUNCTION ...
      F(I)=DBLE(I+I+1)
C
      IF (ICNTRL.GE.0) GOTO 1000
      IF (ICNTRL.EQ.-1) GOTO 2000
      WRITE(6,633) ICNTRL,R
  633 FORMAT(/'  *** ERROR IN POTENL, ICNTRL =',I6,'  R =',E16.8)
      STOP
C
C     ******************************************************************
C     **                                                              **
C     **    CODE BELOW IS FOR AN EVALUATION CALL - CALCULATES P()     **
C     **                                                              **
C     ******************************************************************
 1000 IF (LVRTP) GO TO 1500
C
C     ----- CASE 1 -----
C     EVALUATE RADIAL COEFFICIENTS AS POWERS, EXPONENTIALS OR VSTAR
      IX=0
      IEX=0
      DO 1300 I=1,MXLMB
      SUM=0.D0
      NT=NTERM(I)
      IF (NT.EQ.0) GOTO 1300
      IF (NT.LT.0) GOTO 1250
      DO 1200 IT=1,NT
      IX=IX+1
      NP=NPOWER(IX)
      IF(NP.EQ.0) GOTO 1100
      TERM=R**NP
      IF(ICNTRL.EQ.0) GOTO 1200
      IF(ICNTRL.EQ.1) TERM=DBLE(NP)*TERM/R
      IF(ICNTRL.EQ.2) TERM=DBLE(NP*(NP-1))*TERM/(R*R)
      GOTO 1200
C
 1100 IEX=IEX+1
      TERM=EXP(E(IEX)*R)
      IF(ICNTRL.GT.0) TERM=TERM*E(IEX)**ICNTRL
 1200 SUM=SUM+A(IX)*TERM
      GOTO 1300
 1250 IF(ICNTRL.EQ.0) CALL VSTAR (I,R,SUM)
      IF(ICNTRL.EQ.1) CALL VSTAR1(I,R,SUM)
      IF(ICNTRL.EQ.2) CALL VSTAR2(I,R,SUM)
 1300 P(I)=SUM
      RETURN
C
 1500 IF(ITSAVE.GE.100) GOTO 1900
C
C     ----- CASE 2 -----
C     EXPLICIT PROJECTION OF LEGENDRE COMPONENTS VIA VRTP

c  major mods here 6/29/99 gcm; works only for itype = 3 or 23
c  with vecevalh2co.f 

c  construct vector of potential values at angular integration points

      call vecevalh2co(ntot, distscal*r, tempot)

c  do Gaussian quadrature with existing matrix of basis fcns * weights
c  to produce vector of potential terms p
c  we multiply by FACTOR since that is no longer being done
c  in (nonexistent) vrtp.f

c  escal added 3/25/00 gcm

      call dgemv('N', mxlmb, ntot, escal*FACTOR, x(ixfac+1), mxlmb,
     *     tempot, 1, 0.0d0, p, 1)

      return

c  code between here and statement 1900 dead in this version
c  6/28/99 gcm

      DO 1700 I=1,MXLMB
 1700    P(I)=0.D0
         NTOT=1
         DO 1710 ID=1,NDIM
            INX(ID)=1
C     BELOW COULD BE ELIMINATED BY 'SAVE NTOT'
 1710       NTOT=NTOT*NPTS(ID)
C     START YPT() INDEX = IX;
C     IX COUNTS DOWN LAMBDA THEN 1ST DIMENSION, 2ND DIMENSION, ...
            IX=IXFAC
            DO 1800 I=1,NTOT
               WEIGHT=1.D0
               DO 1810 ID=1,NDIM
                  COSANG(ID)=XPT(INX(ID),ID)
 1810             WEIGHT=WEIGHT*XWT(INX(ID),ID)
                  CALL VRTP(ICNTRL,R,SUM)
                  SUM=SUM*WEIGHT
C     ACCUMULATE CONTRIBUTIONS TO EACH P()
                  DO 1820 IL=1,MXLMB
                     IX=IX+1
 1820                P(IL)=P(IL)+SUM*X(IX)
C     INCREMENT THE INDICES FOR EACH DIMENSION, INX(ID), STARTING W/ 1ST
                     ID=1
 1830                INX(ID)=INX(ID)+1
                     IF (INX(ID).LE.NPTS(ID)) GO TO 1800
C     WE REACH HERE IF WE'VE HIT MAX FOR THIS DIMENSION; START NEXT,
                     INX(ID)=1
                     ID=ID+1
                     IF (ID.LE.NDIM) GO TO 1830
C     IF WE REACH HERE WE SHOULD HAVE COUNTED ALL NTOT ELEMENTS
                     IF (I.EQ.NTOT) GO TO 1800
               WRITE(6,*) ' POTENL. ERROR IN PROJECTION.  NO. TERMS',I
                     STOP
 1800             CONTINUE
      RETURN
C
C     ----- CASE 3 -----
C     UNEXPANDED POT'L AS FUNCTION OF ANGLES, FROM VRTP
 1900 CALL VRTP(ICNTRL,R,P)
      RETURN
C
C     ******************************************************************
C     **                                                              **
C     **    CODE BELOW IS FOR AN INITIALIZATION CALL                  **
C     **                                                              **
C     ******************************************************************
C
 2000 PI=ACOS(-1.D0)
C
C     ------ NEXT TWO STATEMENTS ARE NEEDED IF USING AN INTERNAL   -----
C     ------ X() ARRAY; I.E. NOT USING MOLSCAT /MEMORY/ MECHANISM
C     MX=MXX
C     IXNEXT=1
C     ------------------------------------------------------------------
C
      WRITE(6,634)
c  634 FORMAT(/'  STANDARD MOLSCAT POTENL ROUTINE (AUG 94) ',
c     1  'CALLED FOR POTENTIAL.'//
c     2  '  /POTL/  DATA ARE --')
  634 FORMAT(/' H2-CO vector POTENL ROUTINE (June 99) ',
     1  'CALLED FOR POTENTIAL.'//
     2  '  /POTL/  DATA ARE --')

C     INITIALIZE NAMELIST VARIABLES BEFORE READ
      RM=1.D0
      EPSIL=1.D0
      MXLAM=0
      LMAX=-1
      L2MAX=-1
      MMAX=-1
      IVMIN=-1
      IVMAX=-1
      IHOMO=1
      ICNSYM=1
      IHOMO2=1
      ICNSY2=1
      CFLAG=0
c  distscal and escal initializations added gcm
      distscal=1.0d0
      escal=1.0d0
      DO 2999 ID=1,MXDIM
 2999 NPTS(ID)=0
      LVRTP=.FALSE.
      NPOTL=-1
C
C     NAMELIST/POTL/ RM,EPSIL,MXLAM,MXSYM,LAMBDA,NPOTL,NTERM,
C    1   A,NPOWER,E,CFLAG,LVRTP,NPT,NPS,
C    2   IHOMO,ICNSYM,LMAX,L1MAX,L2MAX,MMAX,IVMIN,IVMAX,
C    3   NPTS,IHOMO2,ICNSY2
C-------------------------------------------------------------------
C     ARRAYS FOR NAMELIST SIMULATOR
C     LOCN(1)=LOC(RM)
C     LOCN(2)=LOC(EPSIL)
C     LOCN(3)=LOC(MXLAM)
C     LOCN(4)=LOC(MXSYM)
C     LOCN(5)=LOC(LAMBDA)
C     LOCN(6)=LOC(NPOTL)
C     LOCN(7)=LOC(NTERM)
C     LOCN(8)=LOC(A)
C     LOCN(9)=LOC(NPOWER)
C     LOCN(10)=LOC(E)
C     LOCN(11)=LOC(CFLAG)
C     INDX(11)=4
C     LOCN(12)=LOC(LVRTP)
C     INDX(12)=3
C     LOCN(13)=LOC(NPT)
C     LOCN(14)=LOC(NPS)
C     LOCN(15)=LOC(IHOMO)
C     LOCN(16)=LOC(ICNSYM)
C     LOCN(17)=LOC(LMAX)
C     LOCN(18)=LOC(L1MAX)
C     LOCN(19)=LOC(L2MAX)
C     LOCN(20)=LOC(MMAX)
C     LOCN(21)=LOC(IVMIN)
C     LOCN(22)=LOC(IVMAX)
C     LOCN(23)=LOC(NPTS)
C     LOCN(24)=LOC(IHOMO2)
C     LOCN(25)=LOC(ICNSY2)
C     CALL NAMLIS('&POTL ',PNAMES,LOCN,INDX,25,IEOF)
C-------------------------------------------------------------------
      READ(5,POTL)
      if ((distscal .ne. 1.0) .or. (escal .ne. 1.0)) then
         write(*, 587) distscal, escal
      end if
 587  format(1x, 'modified potential: distscal, escal = ', 2(F12.6,2x))
C
      IF (NPOTL.NE.-1) WRITE(6,602) NPOTL
  602 FORMAT(/' *** POTENL.  CURRENT CODE IGNORES INPUT &POTL NPOTL =',
     1        I6)
      ITYPE=ITYP-10*(ITYP/10)
      LCALC=.FALSE.
C
C     FOR ITYPE=9, POTIN9 MUST EITHER RESET ITYPE TO ONE OF THE
C     RECOGNISED VALUES OR MUST DO ALL THE REST OF THE SETUP WORK
C
      IF(ITYPE.EQ.9) 
     1  CALL POTIN9(ITYPE,LAM,MXLAM,NPTS,NDIM,XPT,XWT,MXPT,
     2  X,MX,IXFAC)
C     NOTE THAT EVEN IF POTIN9 WAS CALLED, ITYPE MAY NOT BE 9 NOW
      IF(ITYPE.EQ.9) RETURN
C
      IF (CFLAG.EQ.1 .AND. .NOT.(ITYPE.EQ.5.OR.ITYPE.EQ.6)) 
     1  WRITE(6,604) CFLAG,ITYPE
  604 FORMAT(/' *** '/
     2  ' *** POTENL. INPUT &POTL CFLAG =',I2,' NOT CONSISTENT WITH ',
     3  'ITYPE =',I4/' ***',9X,'DO YOU REALLY WANT THIS?'/' ***')
C
      XLAM=.FALSE.
C
C     CHECK FOR LVRTP OR MXLAM.LE.0, ("UNEXPANDED" POTENTIAL CASE).
C
      IF(MXLAM.LE.0) LVRTP=.TRUE.
      IF (.NOT.LVRTP) GO TO 3998
C
      WRITE(6,636)
  636 FORMAT(/'  POTENTIAL IS **NOT** EXPANDED IN ANGULAR FUNCTIONS.'//
     1  '  A SUITABLE VRTP ROUTINE MUST BE SUPPLIED.')
      IF (ITYP.GT.100 .OR.
     1    ITYPE.EQ.1 .OR. ITYPE.EQ.2 .OR. ITYPE.EQ.3. OR.
     2    ITYPE.EQ.5 .OR. ITYPE.EQ.6)
     2    GO TO 3010
      WRITE(6,637)  ITYP
  637 FORMAT('  *** POTENL.  ERROR VRTP NOT SUPPORTED FOR ITYPE =',I6)
      STOP
C
 3010 FACTOR=1.D0
      ITSAVE=ITYP
C     CHECK/PROCESS IHOMO/ICNSYM INPUT
      IF (IHOMO.NE.1.OR.ICNSYM.NE.1.OR.IHOMO2.NE.1.OR.ICNSY2.NE.1) THEN
        WRITE(6,681) IHOMO,ICNSYM,IHOMO2,ICNSY2
  681   FORMAT('  INPUT VALUES ARE IHOMO =',I2,', ICNSYM =',I2,
     1    ', IHOMO2 =',I2,', ICNSY2 =',I2/
     2    '  THESE MAY BE OVERRIDDEN BY VRTP')
C       FOR COMPATIBILITY WITH OLD CODE WHICH USES ICNSYM FOR IHOMO2 ...
        IF (ITYPE.EQ.3.AND.IHOMO2.NE.1.AND.ICNSYM.EQ.1) ICNSYM=IHOMO2
      ENDIF
C     INITIALIZATION CALL TO VRTP.
C     IT MAY USE OR SET RM, EPSIL, IHOMO, ICNSYM
c     this line removed 6/29/99 gcm because setup_h2co is being called later
c      CALL VRTP(ICNTRL,RM,EPSIL)
C
C     CHECK FOR VALID IHOMO, ICNSYM AFTER CALL TO VRTP
      IF (IHOMO.NE.1) THEN
        IF (IHOMO.NE.2) THEN
          WRITE(6,606) IHOMO
  606     FORMAT(/' *** POTENL. ILLEGAL IHOMO =',I6,' FROM &POTL INPUT'
     1       ,' OR VRTP')
          STOP
        ELSE
          WRITE(6,*) ' &POTL INPUT OR VRTP SPECIFIES',
     1               ' HOMONUCLEAR SYMMETRY.'
        ENDIF
      ENDIF
      IF (ICNSYM.LE.0) THEN
        WRITE(6,*) ' *** POTENL. ILLEGAL &POTL ICNSYM =',ICNSYM
        STOP
      ELSEIF (ICNSYM.GT.1) THEN
        WRITE(6,*) ' ICNSYM INPUT OR FROM VRTP SPECIFIES',
     1             ' AXIAL SYMMETRY, ICNSYM =',ICNSYM
      ENDIF
C *** CHECK IHOMO2, ICNSY2 ???
C
      IF(ITYP.GT.100.AND.MXLAM.LE.0) GOTO 3100
C
C     ******************************************************************
C     CODE BELOW IS CASE 2 -- PROJECTED EXPANSION USING VRTP
C       SYMMETRIES INPUT VIA *EITHER* LMAX *OR* MXLAM,LAMBDA
C       LATTER TAKES PRECEDENCE IF BOTH ARE SPECIFIED.
C     ******************************************************************
C     NPOTL FOR THIS CASE CALCULATED IN CODE BEGINNING AT 3999
C
      IF (LMAX.LT.0.AND.MXLAM.LE.0) THEN
        WRITE(6,*) ' *** POTENL. LMAX.LT.0.AND.MXLAM.LE.0'
        WRITE(6,*) '             YOU MUST SPECIFY SYMMETRIES VIA ONE',
     1             ' OR THE OTHER IN &POTL'
        STOP
      ELSEIF (LMAX.GE.0.AND.MXLAM.GT.0) THEN
        WRITE(6,607) LMAX
  607   FORMAT('  *** POTENL. IGNORING INPUT &POTL LMAX =',I4,
     1         ' IN FAVOR OF MXLAM, LAMBDA() VALUES')
        LMAX=-1
      ENDIF
C
      IF (ITYP.GT.100) THEN
        WRITE(6,699)
  699   FORMAT(/' *** NOTE *** REQUESTED PROJECTED EXPANSION IS '
     1         ,'GENERALLY NOT DESIRABLE FOR IOS CALCULATIONS.'/
     2          '              STANDARD IOS/VRTP PROCESSING CAN BE'
     3         ,' OBTAINED BY SETTING MXLAM=0 IN &POTL'/)
C       IN EVALUATION CALL, FLAG TO PROJECT IS ITSAVE.LT.100
        ITSAVE=ITSAVE-10*(ITSAVE/10)
      ENDIF
C
C     FOR THE COUPLING CASES ALLOWED HERE (1,2,3,5,6) PROJECTING OUT
C     THE POTENTIAL  COEFFICIENTS INVOLVES A QUADRATURE OVER THETA.
C     GET GAUSS-LEGENDRE QUADRATURE POINTS AND WEIGHTS,
C     AND CHECK THAT NUMBER OF POINTS IS SENSIBLE.
C
      WRITE(6,635) NPT
  635 FORMAT(I4,'-POINT GAUSSIAN QUADRATURE REQUESTED TO PROJECT',
     1   ' COMMON THETA-1 COMPONENT')
      IF(LMAX.GE.0) THEN
        MXLM=LMAX+1
      ELSE
        IF(ITYPE.EQ.1) THEN
          IADD=1
        ELSEIF(ITYPE.EQ.2) THEN
          IADD=3
        ELSEIF(ITYPE.EQ.3) THEN
          IADD=3
        ELSEIF(ITYPE.EQ.5 .OR. ITYPE.EQ.6) THEN
          IADD=2
        ELSE
          WRITE(6,638) ITYPE
  638     FORMAT(/' *** POTENL. ILLEGAL LOGICAL PATH.  ITYPE =',I6)
          STOP
        ENDIF
        MXLM=0
        IND=1
        DO 3011 I=1,MXLAM
        MXLM=MAX(MXLM,LAMBDA(IND))
 3011   IND=IND+IADD
        MXLM=MXLM+1
      ENDIF
C
      IF(MXLM.GT.NPT) WRITE(6,648) NPT,MXLM
  648 FORMAT(I4,'-POINT QUADRATURE IS INSUFFICIENT TO PROJECT OUT',
     1   ' LEGENDRE COMPONENTS REQUESTED'/'     INCREASED TO ',I3,
     2   ' ACCORDINGLY')
      NPT=MAX(NPT,MXLM)
C     NB ABOVE CODE GUARANTEES THAT NPT.GE.1
      IF(NPT.GT.MXPT) GO TO 9400
C
      NEXP=NPT
      CALL GAUSSP(-1.D0,1.D0,NPT,XPT(1,1),XWT(1,1))
      IF(NPT.NE.NEXP) THEN
C       NB THIS BRANCH SHOULD NOT OCCUR WITH CURRENT GAUSSP
        WRITE(6,653) NEXP
  653   FORMAT(I4,'-POINT GAUSS-LEGENDRE QUADRATURE IS NOT AVAILABLE')
        STOP
      ENDIF
C
      IF(IHOMO.EQ.2) THEN
        DO 3014 IPT=1,NPT/2
 3014   XWT(IPT,1)=2.D0*XWT(IPT,1)
        NPT=(NPT+1)/2
        WRITE(6,*) ' HOMONUCLEAR SYMMETRY: ONLY HALF OF',
     1             ' THE THETA-1 POINTS WILL BE USED'
      ENDIF
C
C     SET UP OTHER QUADRATURE POINTS AND WEIGHTS FOR PROJECTING
C     POTENTIAL COMPONENTS FOR ITYPE=1,2,3,5,6
C
      IF (ITYPE.EQ.1)  GO TO 3001
      IF (ITYPE.EQ.2)  GO TO 3002
      IF (ITYPE.EQ.3)  GO TO 3003
      IF (ITYPE.EQ.5)  GO TO 3005
      IF (ITYPE.EQ.6)  GO TO 3005
      WRITE(6,638) ITYPE
      STOP
C
C     ITYPE = 1: ATOM + LINEAR RIGID ROTOR
C
 3001 IF(LMAX.GE.0) THEN
        LCALC=.TRUE.
        MXLAM=0
        DO 3012 L=0,LMAX,IHOMO
        MXLAM=MXLAM+1
        IF (MXLAM.GT.MXLMB) GO TO 9500
 3012   LAM(MXLAM)=L
      ELSE
        DO 3112 I=1,MXLAM
 3112   LAM(I)=LAMBDA(I)
      ENDIF
      XLAM=.TRUE.
C
      NDIM=1
      IF (NDIM.GT.MXDIM) GO TO 9300
      NTOT=NPT
      IXFAC=MX-MXLAM*NTOT
      MX=IXFAC
      IF (MX+1.LT.IXNEXT) GO TO 9600
      IX=IXFAC
      DO 3016 IP=1,NPT
      DO 3016 IL=1,MXLAM
      L=LAM(IL)
      IF(MOD(L,IHOMO).NE.0) THEN
        WRITE(6,668) IL,IHOMO,ICNSYM,L
  668   FORMAT(/' *** POTENL.  SYMMETRY',I4,' IS INCONSISTENT ',
     1          'WITH IHOMO =',I2,' OR ICNSYM =',I2,'  INDICES:',5I4)
        STOP
      ENDIF
      IX=IX+1
 3016 X(IX)=SQRT(DBLE(L)+0.5D0)*PLM(L,0,XPT(IP,1))
      GOTO 3999
C
C     ITYPE = 2: ATOM + VIBRATING DIATOM
C
 3002 IF(LMAX.GE.0) THEN
        LCALC=.TRUE.
        IF (IVMIN.LT.0) THEN
          WRITE(6,*) ' *** POTENL. IVMIN MUST BE SPECIFIED IN &POTL'
          WRITE(6,*) '             TO GENERATE SYMMETRIES AS REQUESTED'
     1               ,' BY &POTL LMAX',LMAX
          STOP
        ENDIF
        IF (IVMAX.LT.IVMIN) THEN
          WRITE(6,*) ' *** POTENL. IVMAX.LT.IVMIN INCREASED TO IVMIN'
          IVMAX=IVMIN
        ENDIF
C       NB GIVEN /CMBASE/ WE COULD GET IVMIN,IVMAX FROM JLEVEL
        MXLAM=0
        DO 3018 L=0,LMAX,IHOMO
        DO 3018 IV=IVMIN,IVMAX
        DO 3018 JV=IVMIN,IV
        MXLAM=MXLAM+1
        IF (3*MXLAM.GT.MXLMB) GO TO 9500
        LAM(3*MXLAM-2)=L
        LAM(3*MXLAM-1)=IV
 3018   LAM(3*MXLAM  )=JV
      ELSE
        IF (3*MXLAM.GT.MXLMB) GO TO 9500
        DO 3118 I=1,3*MXLAM
 3118   LAM(I)=LAMBDA(I)
      ENDIF
      XLAM=.TRUE.
C
      WRITE(6,672) NPS
  672 FORMAT(I4,'-POINT GAUSSIAN QUADRATURE REQUESTED TO INTEGRATE ',
     1   ' OVER HARMONIC OSCILLATOR FUNCTIONS')
      MAXV=0
      DO 3021 I=1,MXLAM
      MAXV=MAX(MAXV,LAM   (3*I))
 3021 MAXV=MAX(MAXV,LAM   (3*I-1))
      IF(2*MAXV-1.GT.NPS) THEN
        NPSOLD=NPS
        NPS=2*MAXV-1
        WRITE(6,670) NPSOLD,MAXV,NPS
  670   FORMAT(/'  *** WARNING IN POTENL - ',I2,'-POINT QUADRATURE ',
     1    'NOT ENOUGH FOR MATRIX ELEMENTS UP TO V OR K =',I3/
     2    6X,'NPS INCREASED TO',I3)
      ENDIF
      IF (NPS.GT.MXPT) GO TO 9400
      NPSOLD=NPS
      CALL GAUSHP(NPS,XPT(1,2),XWT(1,2))
      IF (NPS.NE.NPSOLD) THEN
        WRITE(6,*) ' *** POTENL. GAUSHP CANNOT SUPPLY REQUESTED NPS',NPS
        STOP
      ENDIF
      IF (MAXV+1.GT.MXHERM) THEN
        WRITE(6,*) ' *** POTENL. DIMENSION OF H INSUFFICIENT FOR',
     1             'REQUIRED HERMITE POLYNOMIALS'
        WRITE(6,*) ' ***         SUPPPLIED, REQUIRED',MXHERM,MAXV+1
        STOP
      ENDIF
C
      NDIM=2
      IF (NDIM.GT.MXDIM) GO TO 9300
      NTOT=NPT*NPS
      IXFAC=MX-MXLAM*NTOT
      MX=IXFAC
      IF (MX+1.LT.IXNEXT) GO TO 9600
      IX=IXFAC
      DO 3020 IPX=1,NPS
C     GET HERMITE POLYNOMIALS AND NORMALISE THEM
      CALL HERM(H,MAXV+1,XPT(IPX,2))
      SUM=SQRT(PI)
      DO 3022 NV=1,MAXV+1
      H(NV)=H(NV)/SQRT(SUM)
 3022 SUM=SUM*DBLE(2*NV)
      DO 3020 IPT=1,NPT
      DO 3020 IL=1,MXLAM
      L=LAM(3*IL-2)
      IX=IX+1
 3020 X(IX)=SQRT(DBLE(L)+0.5D0)*PLM(L,0,XPT(IPT,1))*
     1           H(1+LAM(3*IL-1))*H(1+LAM(3*IL))
      GOTO 3999
C
C     ITYPE = 3 LINEAR ROTOR - LINEAR ROTOR
C
 3003 IF (L1MAX.GE.0) THEN
        LCALC=.TRUE.
        IF (L2MAX.LT.0) L2MAX=L1MAX
        MXLAM=0
        DO 3034 L1=0,L1MAX,IHOMO
        DO 3034 L2=0,L2MAX,ICNSYM
        LMIN=ABS(L1-L2)
C       19 OCT 95: LMAX->LTOP BELOW
        LTOP=L1+L2
        DO 3034 LL=LMIN,LTOP,2
        MXLAM=MXLAM+1
        IF (3*MXLAM.GT.MXLMB) GO TO 9500
        LAM(3*MXLAM-2)=L1
        LAM(3*MXLAM-1)=L2
 3034   LAM(3*MXLAM)=LL
      ELSE
        IF (3*MXLAM.GT.MXLMB) GO TO 9500
        L1MAX=0
        L2MAX=0
        DO 3134 I=1,MXLAM
        LAM(3*I-2)=LAMBDA(3*I-2)
        L1MAX=MAX(L1MAX,LAMBDA(3*I-2))
        LAM(3*I-1)=LAMBDA(3*I-1)
        L2MAX=MAX(L2MAX,LAMBDA(3*I-1))
 3134   LAM(3*I)=LAMBDA(3*I)
      ENDIF
      XLAM=.TRUE.
      MAXV=MIN(L1MAX,L2MAX)
      IF (NPS.LE.L2MAX) WRITE(6,648) NPS,L2MAX
      NPS=MAX(NPS,L2MAX)
      NEXP=NPS
      WRITE(6,685) NPS
  685 FORMAT(I4,'-POINT GAUSSIAN QUADRATURE REQUESTED TO PROJECT',
     1   ' LEGENDRE COMPONENTS - MOLECULE 2')
      CALL GAUSSP(-1.D0,1.D0,NPS,XPT(1,2),XWT(1,2))
      IF(NPS.NE.NEXP) THEN
C       NB THIS BRANCH SHOULD NOT OCCUR WITH CURRENT GAUSSP
        WRITE(6,653) NEXP
        STOP
      ENDIF
C     IF SYMMETRIC 2ND MOLECULE, REDUCE POINTS/INCREASE WEIGHTS
      IF(ICNSYM.EQ.2) THEN
        DO 3314 IPT=1,NPS/2
 3314   XWT(IPT,2)=2.D0*XWT(IPT,2)
        NPS=(NPS+1)/2
        WRITE(6,*) ' HOMONUCLEAR MOLECULE 2:',
     1             ' ONLY HALF THE POINTS WILL BE USED'
      ENDIF
C     SET UP GAUSS-MEHLER INTEGRATION FOR PHI ON (0,PI)
      WRITE(6,675) NPTS(3)
      IF (NPTS(3).LT.MAXV) THEN
        WRITE(6,*) ' *** POTENL. INSUFFICIENT NUMBER OF POINTS',
     1             ' REQUESTED FOR PHI',NPTS(3)
        WRITE(6,*) '             INCREASED TO',MAXV
        NPTS(3)=MAXV
      ENDIF
      IF (NPTS(3).GT.MXPT) GO TO 9400
      FACTL=PI/DBLE(NPTS(3))
      TH=-FACTL/2.D0
      DO 3342 IX=1,NPTS(3)
      TH=TH+FACTL
      XWT(IX,3)=(2.D0*FACTL)
 3342 XPT(IX,3)=TH
      NDIM=3
      IF (NDIM.GT.MXDIM) GO TO 9300
      NTOT=NPTS(1)*NPTS(2)*NPTS(3)
      IXFAC=MX-MXLAM*NTOT
      MX=IXFAC
      IF (MX+1.LT.IXNEXT) GO TO 9600

C
      IX=IXFAC
      PI8=8.D0*PI*PI
c     mods here 6/28/99 gcm to multiply x() by weight terms
c     and fill angular arrays for use by vecsetuph2co
c
      i = 1
      do IP3=1,NPTS(3)
         do IPX=1,NPTS(2)
            do IPT=1,NPTS(1)
               cth1vals(i) = XPT(IPT,1)
               cth2vals(i) = XPT(IPX,2)
               phivals(i) = XPT(IP3,3)
               i = i+1
               tempwt = XWT(IPT,1)*XWT(IPX,2)*XWT(IP3,3)
               do IL=1,MXLAM
                  L1=LAM(3*IL-2)
                  L2=LAM(3*IL-1)
                  LL=LAM(3*IL)
                  IX=IX+1
                  X(IX)=YRR(L1,L2,LL,XPT(IPT,1),XPT(IPX,2),XPT(IP3,3))
     *                 *tempwt
     *                 *PI8/F(LL)
               end do
            end do
         end do
      end do
      

c     call setuph2co to evaluate angular coefficients at each angle triple
      call vecsetuph2co(ntot)
c     specify return values should be in cm-1
      Econv = 349.755d0

c  Econv changed here to check whether Szalewicz' values are affected
c      349.63 is incorrect value used in JCP paper
c      Econv = 349.63d0

c$$$C     N.B. USE OF YRR MIGHT BE EXPENSIVE; CODE COULD BE MODIFIED
c$$$C       SIMILARLY TO THAT IN IOSB1
c$$$      
c$$$      DO 3329 IP3=1,NPTS(3)
c$$$      DO 3329 IPX=1,NPTS(2)
c$$$      DO 3329 IPT=1,NPTS(1)
c$$$      DO 3329 IL=1,MXLAM
c$$$      L1=LAM(3*IL-2)
c$$$      L2=LAM(3*IL-1)
c$$$      LL=LAM(3*IL)
c$$$      IX=IX+1
c$$$ 3329 X(IX)=YRR(L1,L2,LL,XPT(IPT,1),XPT(IPX,2),XPT(IP3,3))*PI8/F(LL)
      GOTO 3999
C
C     ITYPE = 5 OR 6: ATOM + NON-LINEAR RIGID ROTOR
C
 3005 IF(LMAX.GE.0) THEN
        LCALC=.TRUE.
        IF(MMAX.LT.0) MMAX=LMAX
        MXLAM=0
        DO 3024 L=0,LMAX
        DO 3024 M=0,MIN(L,MMAX),ICNSYM
C       ONLY INCLUDE SYMMETRIES CONSISTENT W/ IHOMO, ICNSYM
        IF(MOD(L+M,IHOMO).NE.0) GOTO 3024
        MXLAM=MXLAM+1
        IF (2*MXLAM.GT.MXLMB) GO TO 9500
        LAM(2*MXLAM-1)=L
        LAM(2*MXLAM  )=M
 3024   CONTINUE
      ELSE
        IF (2*MXLAM.GT.MXLMB) GO TO 9500
        DO 3124 I=1,2*MXLAM
 3124   LAM(I)=LAMBDA(I)
      ENDIF
      XLAM=.TRUE.
C
      WRITE(6,675) NPS
  675 FORMAT(I4,'-POINT QUADRATURE REQUESTED TO PROJECT OUT',
     1   ' PHI COMPONENTS')
      MAXV=0
      DO 3025 I=1,MXLAM
 3025 MAXV=MAX(MAXV,LAM   (2*I))
      IF(MAXV.GT.(NPS-1)*ICNSYM) THEN
        NPSOLD=NPS
        NPS=1+(MAXV+ICNSYM-1)/ICNSYM
        WRITE(6,670) NPSOLD,MAXV,NPS
      ENDIF
      IF (NPS.GT.MXPT) GO TO 9400
C
      NDIM=2
      IF (NDIM.GT.MXDIM) GO TO 9300
      NTOT=NPT*NPS
      DO 3026 IPX=1,NPS
      XPT(IPX,2)=PI*DBLE(2*IPX-1)/DBLE(2*ICNSYM*NPS)
 3026 XWT(IPX,2)=SQRT(PI+PI)/DBLE(NPS)
      IXFAC=MX-MXLAM*NTOT
      MX=IXFAC
      IF (MX+1.LT.IXNEXT) GO TO 9600
C
      IX=IXFAC
      DO 3029 IPX=1,NPS
      DO 3029 IPT=1,NPT
      DO 3029 IL=1,MXLAM
      L=LAM(2*IL-1)
      M=LAM(2*IL)
      IF(MOD(L+M,IHOMO).NE.0 .OR. MOD(M,ICNSYM).NE.0) THEN
        WRITE(6,668) I,IHOMO,ICNSYM,L,M
        STOP
      ENDIF
      IX=IX+1
 3029 X(IX)=PLM(L,M,XPT(IPT,1))*COS(DBLE(M)*XPT(IPX,2))
      GOTO 3999
C
C    *******************************************************************
C       CODE BELOW IS CASE 3 - NON-EXPANDED POTENTIAL, IOS ONLY
C    *******************************************************************
C     MXLAM,NPOTL SET HERE
C
 3100 IF(ITYP.EQ.102) GO TO 3192
C     BELOW IS UNIFIED CODE FOR ITYPE=101,103,105,106 (& 102 W/MXLAM=0)
      NQPL=1
      IF(ITYP.EQ.103) NQPL=3
      IF(ITYP.EQ.105 .OR. ITYP.EQ.106) NQPL=2
 3190 DO 3101 I=1,NQPL
 3101 LAM(I)=0
      XLAM=.TRUE.
      NPOTL=1
      MXLAM=1
      GOTO 9050
C
C     CODE FOR ATOM-VIBRATING DIATOM IOS, IE., CLARY'S VCC-IOS
C       WHERE THE ANGLE DEPENDENCE OF POTENTIAL IS NOT EXPANDED.
C>>   IT WOULD MAKE GOOD SENSE TO USE IVMIN,IVMAX TO GENERATE HERE.
C
 3192 NQPL=3
C     IF MXLAM=0, ASSUME V=V'=0; PROCESS SAME AS OTHER ITYPES
      IF(MXLAM.EQ.0) GOTO 3190
      MXLAM=ABS(MXLAM)
      WRITE(6,621) MXLAM
  621 FORMAT(/'  POTENL, ITYPE=102.  NEGATIVE MXLAM REQUESTS',I3,
     1       ' SYMMETRIES'//'  SYMMETRY    LAMBDA     VIB1      VIB2')
      DO 3104 I=1,MXLAM
      IF (LAMBDA(3*I-2).EQ.0) GO TO 3102
      WRITE(6,622)
  622 FORMAT('  *** WARNING.  INPUT LEGENDRE SYMMETRY .GT. ZERO BELOW',
     1       ' WILL BE IGNORED AND SET TO ZERO.')
 3102 LAM(3*I-2)=0
      LAM(3*I-1)=LAMBDA(3*I-1)
      LAM(3*I  )=LAMBDA(3*I  )
 3104 WRITE(6,623) I,LAMBDA(3*I-2),LAMBDA(3*I-1),LAMBDA(3*I)
  623 FORMAT(1X,I8,I9,2I10)
      XLAM=.TRUE.
      NPOTL=1
      GOTO 9050
C
C     STATEMENT BELOW BEGINS PROCESSING FOR LVRTP=.FALSE.
 3998 IF (LMAX.GE.0) THEN
        WRITE(6,*) ' *** POTENL. &POTL REQUESTS MXLAM.GT.0 AND ',
     1             'LVRTP=.FALSE.'
        WRITE(6,*) '             &POTL LMAX.GT.0 IS IGNORED;',
     1             ' AND MXLAM, LAMBDA INPUT USED INSTEAD'
        LMAX=-1
      ENDIF
C
C     ATTEMPT TO PROCESS ITYPE AND POTENTIAL DESCRIPTION NUMBERS
 3999 QOUT=.TRUE.
      NPOTL=MXLAM
      NQPL=1
      WRITE(6,639)
  639 FORMAT(/'  ANGULAR DEPENDENCE OF POTENTIAL EXPANDED IN TERMS OF')
      ITYPE=ITYP-10*(ITYP/10)
      IF(ITYPE.EQ.1) GOTO 2001
      IF(ITYPE.EQ.2) GOTO 2002
      IF(ITYPE.EQ.3) GOTO 2003
      IF(ITYPE.EQ.4) GOTO 2004
      IF(ITYPE.EQ.5) GOTO 2005
      IF(ITYPE.EQ.6) GOTO 2005
      IF(ITYPE.EQ.7) GOTO 2002
      IF(ITYPE.EQ.8) GOTO 2008
C
      WRITE(6,640) ITYPE
  640 FORMAT(/' *** POTENL. ITYPE =',I4,' CANNOT BE PROCESSED TO',
     1   ' DETERMINE THE POTENTIAL SYMMETRY LABLES')
      QOUT=.FALSE.
      GOTO 2100
C
 2001 NQPL=1
      QNAME(1)=QTYPE(1)
      WRITE(6,641)
  641 FORMAT('  LEGENDRE POLYNOMIALS, P(LAMBDA).')
      IF(LCALC) WRITE(6,615) LMAX,IHOMO
  615 FORMAT('  POTENTIAL SYMMETRIES GENERATED FROM LMAX =',I3,
     1   ' AND IHOMO =',I2)
      GOTO 2100
C
 2002 NQPL=3
      QNAME(1)=QTYPE(1)
      QNAME(2)=QTYPE(7)
      QNAME(3)=QTYPE(8)
      WRITE(6,641)
      WRITE(6,642)
  642 FORMAT('  INTEGRATED OVER DIATOM VIBRATIONAL FUNCTIONS')
      IF(ITYPE.EQ.2) THEN
        IF(LCALC) WRITE(6,616) LMAX,IHOMO,IVMIN,IVMAX
  616   FORMAT('  POTENTIAL SYMMETRIES GENERATED FROM LMAX =',I3,
     1   ' AND IHOMO =',I2/'  WITH V FROM',I2,' TO',I2)
      ELSEIF (ITYPE.EQ.7) THEN
        WRITE(6,643)
  643   FORMAT('  FOR EACH PAIR OF V,J LEVELS')
        NQPL=5
        QNAME(3)=QTYPE(9)
        QNAME(4)=QTYPE(8)
        QNAME(5)=QTYPE(10)
      ENDIF
C     DETERMINE NPOTL FOR USE OF IV(); ITYPE=2 AND 7 IN THIS VERSION
      NPOTL=0
      IF (XLAM) THEN
        DO 2010 I=1,MXLAM
 2010   NPOTL=MAX0(NPOTL,LAM((I-1)*NQPL+1))
      ELSE
        DO 2110 I=1,MXLAM
 2110   NPOTL=MAX0(NPOTL,LAMBDA((I-1)*NQPL+1))
      ENDIF
      NPOTL=NPOTL+1
      GOTO 2100
C
 2003 NQPL=3
      QNAME(1)=QTYPE(4)
      QNAME(2)=QTYPE(5)
      QNAME(3)=QTYPE(6)
      WRITE(6,644)
  644 FORMAT('  CONTRACTED NORMALISED SPHERICAL HARMONICS, SUM',
     1   '(M1,M2,M) C(L1,M1,L2,M2,L,M) Y(L1,M1) Y(L2,M2) Y(L,M)'/
     2   '  SEE RABITZ, J. CHEM. PHYS. 57, 1718 (1972)')
      IF(LCALC) THEN
        WRITE(6,*) ' FOR MOLECULE - 1'
        WRITE(6,615) L1MAX,IHOMO
        WRITE(6,*) ' FOR MOLECULE - 2'
        WRITE(6,615) L2MAX,ICNSYM
      ENDIF
      GOTO 2100
C
 2004 NQPL = 4
      QNAME(1) = QTYPE(4)
      QNAME(2) = QTYPE(3)
      QNAME(3) = QTYPE(5)
      QNAME(4) = QTYPE(6)
      WRITE(6,448)
  448 FORMAT(' CONTRACTION OF SPHERICAL HARMONICS AND ROTATION',
     1       'MATRICES'/
     2  '     SEE T.R. PHILLIPS, ET AL. JCP 101, 5824 (1994)')
      GO TO 2100
C
 2005 NQPL=2
      QNAME(1)=QTYPE(1)
      QNAME(2)=QTYPE(2)
      WRITE(6,645)
  645 FORMAT('  NORMALISED SPHERICAL HARMONICS: (Y(LAM,MU) + ',
     1       '(-)**MU Y(LAM,-MU)) / (1+DELTA(MU,0))')
      IF(LCALC) WRITE(6,617) LMAX,IHOMO,MMAX,ICNSYM
  617 FORMAT('  POTENTIAL SYMMETRIES GENERATED FROM LMAX =',I3,
     1   ', IHOMO =',I2,', MMAX =',I3,' AND ICNSYM =',I2)
      IF(CFLAG.EQ.1) THEN
        IF(LVRTP) THEN
          WRITE(6,662)
        ELSE
          WRITE(6,646)
  646     FORMAT(/' COEFFICIENTS IN POTENTIAL WILL BE MULTIPLIED BY ',
     1    'SQRT(4*PI/(2*LAM+1)) TO BRING POTENTIAL INTO CORRECT FORM')
        ENDIF
      ENDIF
      GOTO 2100
C
C     SEEMS THAT CODE BELOW TREATS NPOTL SAME AS VERSION 9 (SG JAN 94)
 2008 NQPL=2
      QNAME(1)=QTYPE(4)
      QNAME(2)=QTYPE(5)
      NPOTL=NPTL
      WRITE(6,647) NPOTL
  647 FORMAT('  SURFACE FOURIER COMPONENTS'/'  NPOTL =',I2,
     1   ' FROM SURBAS')
      GOTO 2100
C
C    *******************************************************************
C       CODE BELOW IS MAINLY FOR CASE 1 - EXPANDED POTENTIAL
C       USING NTERM,NPOWER,A,E *OR* VSTAR MECHANISM
C    *******************************************************************
C       HOWEVER, CASE 2 - EXPANDED POT'L PROJECTED FROM VRTP
C       ALSO RUNS THROUGH THIS CODE, BUT DOES LITTLE
C    *******************************************************************
C
 2100 IF (.NOT.XLAM.AND.NQPL*MXLAM.GT.MXL) WRITE(6,650) MXLAM,NQPL,MXL
  650 FORMAT(/' *** POTENL. MXLAM =',I4,' AND NQPL =',I2,
     1       '  APPEAR TO EXCEED INTERNAL STORAGE IN LAMBDA(',I5,')'/
     2       '              WILL ATTEMPT TO PROCEED.')
      IX=0
      IEX=0
      IQ=0
      NPX=0
      DO 9000 I=1,MXLAM
C     OUTPUT SYMMETRY DESCRIPTION ONLY IF MXLAM,LAMBDA WERE USED
C       I.E., LCALC=.FALSE.
      IF(.NOT.LCALC) THEN
        WRITE(6,651) I
  651   FORMAT(/'  INTERACTION POTENTIAL FOR SYMMETRY TYPE NUMBER',I4)
        IF(QOUT) WRITE(6,652) (QNAME(J),LAMBDA(IQ+J),J=1,NQPL)
  652   FORMAT('  WHICH HAS ',6(A8,I3,3X))
        WRITE(6,654)
  654   FORMAT(1X)
      ENDIF
      IQ=IQ+NQPL
      NT=NTERM(I)
C     FOR CASE 2, LVRTP=.TRUE. AND WE SKIP PROCESSING
      IF(LVRTP .OR. NT.EQ.0) GOTO 9000
      IF(NT.LT.0) GOTO 8800
      DO 8700 IT=1,NT
      IX=IX+1
      IF(IX.GT.IXMX) THEN
        WRITE(6,9101) IXMX
 9101   FORMAT(/'  *** POTENL.  DIMENSION IXMX EXCEEDED',I6)
        STOP
      ENDIF
      IF(NPOWER(IX).LT.0) GOTO 8200
      IF(NPOWER(IX).EQ.0) GOTO 8000
      WRITE(6,655) IX,NPOWER(IX)
  655 FORMAT(/'  * * * WARNING - POSITIVE EXPONENT OF R ILLEGAL',2I6/
     1   '  NEGATIVE OF SUPPLIED VALUE ASSUMED')
      IF(NPOWER(IX).GT.12 .OR. NPOWER(IX).LT.3) STOP
      NPOWER(IX)=-NPOWER(IX)
      GOTO 8200
C
 8000 IEX=IEX+1
      IF(IEX.GT.IEXMX) THEN
        WRITE(6,9201) IEXMX
 9201   FORMAT(/'  *** POTENL.  DIMENSION IEXMX EXCEEDED',I6)
        STOP
      ENDIF
      IF(E(IEX).LT.0.D0) GOTO 8100
      WRITE(6,656) E(IEX)
  656 FORMAT(/'  * * * WARNING - POTENTIAL CONTAINS INCREASING',
     1   ' EXPONENTIAL =',D16.8)
C
 8100 WRITE(6,657) A(IX), E(IEX)
  657 FORMAT(15X,D16.8,' * EXP(',F10.4,' * R )')
      IF(CFLAG.EQ.1) A(IX)=A(IX)*SQRT(4.D0*PI
     1   /DBLE(2*LAMBDA(IQ-NQPL+1)+1))
      GOTO 8700
C
 8200 WRITE(6,658) A(IX), NPOWER(IX)
  658 FORMAT(15X,D16.8,' * R **',I3)
      IF(CFLAG.EQ.1) A(IX)=A(IX)*SQRT(4.D0*PI
     1   /DBLE(2*LAMBDA(IQ-NQPL+1)+1))
      DO 8400 INPX=1,NPX
      IF(NPOWER(IX).EQ.NPUNI(INPX)) GOTO 8700
 8400 CONTINUE
 8500 NPX=NPX+1
      IF(NPX.GT.NPXMX) THEN
        WRITE(6,9301) NPXMX
 9301   FORMAT(/'  *** POTENL. DIMENSION NPXMX EXCEEDED',I6)
        STOP
      ENDIF
      NPUNI(NPX)=NPOWER(IX)
C
 8700 CONTINUE
      GOTO 9000
 8800 CALL VINIT(I,RM,EPSIL)
      IF(CFLAG.EQ.1) WRITE(6,662)
  662 FORMAT(' *** WARNING. SETTING CFLAG=1 HAS NO EFFECT',
     1   ' EXCEPT WHEN THE POTENTIAL IS SUPPLIED IN ARRAY A')
 9000 CONTINUE
      WRITE(6,663) NPX
  663 FORMAT(/'  NUMBER OF UNIQUE POWERS =',I4)
C     IF(NPX.EQ.0) GOTO 9020   -- NOT REQUIRED IN FORTRAN 77
      DO 9010 I=1,NPX
 9010 WRITE(6,664) I, NPUNI(I)
  664 FORMAT('  POWER',I3,' =',I4)
 9020 CONTINUE
C
C     IF LAM HAS NOT YET BEEN FILLED, GET FROM LAMBDA
      IF (XLAM) GO TO 9050
      IF (MXLAM*NQPL.GT.MXLMB) GO TO 9500
      DO 9030 I=1,MXLAM*NQPL
 9030 LAM(I)=LAMBDA(I)
      XLAM=.TRUE.
C
C     COMMON RETURN POINT FOR ALL INITIALIZATIONS.
C     SET VALUES BACK IN CALLING PARAMETERS.
C
 9050 WRITE(6,665) EPSIL,RM,MXLAM,NPOTL
  665 FORMAT(/'  POTENL PROCESSING FINISHED.'//
     1   '  ENERGY IN UNITS OF EPSILON =',F15.5,' CM-1'/
     2   '  R      IN UNITS OF RM      =',F15.5,' ANGSTROMS'//
     3   '  MXLAM =',I5/'  NPOTL =',I5)
C
      R=RM
      P(1)=EPSIL
      MPOTL=NPOTL
      MXLMB=MXLAM
      RETURN
C
C     ********** ERROR CONDITIONS **********
C
 9300 WRITE(6,9301) NDIM,MXDIM
 9306 FORMAT(/' *** POTENL. PROJECTED POTENTIAL HAS',I3,
     1       ' DIMENSIONS, BUT MXDIM=',I3)
      STOP
 9400 WRITE(6,9401) NPT,NPS,MXPT
 9401 FORMAT(/' *** POTENL. EITHER NPT OR NPS EXCEEDS MXPT'
     2      /'  NPT =',I6,'  NPS =',I6/'  MXPT=',I7)
C       WRITE(6,649) NPT,MXPT
      STOP
 9500 WRITE(6,9501) MXLMB,MXLAM
 9501 FORMAT(/' *** POTENL. DIMENSION OF EXTERNAL LAM ARRAY EXCEEDED'/
     1        '  SIZE PASSED FROM CALLING PROGRAM (MXLMB) =',I8/
     2        '  OFFENDING VALUE OF MXLAM =',I8)
      STOP
C
C     BELOW IS REACHED IF THERE WAS NOT ENOUGH ROOM IN THE X ARRAY TO
C       STORE THE PROJECTION COEFFS.  IF USING /MEMORY/...X, IT IS
C       POSSIBLE FOR THE CODE HERE TO OVERWRITE THE LAM ARRAY WITH
C       COEFFS.  HOWEVER, THE PROGRAM SHOULD THEN TERMINATE WHEN CHKSTR
C       IS CALLED FROM DRIVER AFTER RETURN FROM POTENL INITIALIZATION.
 9600 NREQ=MXLAM*(NPT+NPS)
      MXSTRT=MX+NREQ
      WRITE(6,9601) NPT,NPS,MXLAM,NREQ,MXSTRT,MXSTRT-IXNEXT+1
 9601 FORMAT(' *** POTENL. NOT ENOUGH ROOM FOR PROJECTION COEFFICIENTS'/
     1       '     REQUIRES (',I4,' +',I4,') * ',I4,' =',I8/
     2       '     OF',I8,' ORIGINALLY SUPPLIED IN X(), ONLY',I8,
     3       '  WERE AVAILABLE.')
      STOP
      END


      subroutine vrtp(icall, r, P)
c  dummy version to eliminate link errors for routine that should
c     never be called
      implicit double precision (a-h, o-z)
      dimension p(1)
      write(*, 100) 
 100  format( ' Surprising call to vrtp()')
      return
      end

      SUBROUTINE POTIN9(ITYPE,LAM,MXLAM,NPTS,NDIM,XPT,XWT,MXPT,X,MX,
     1  IXFAC)
      DIMENSION XPT(MXPT,NDIM),XWT(MXPT,NDIM),NPTS(NDIM),
     1  LAM(MXLAM),X(MX)
      WRITE(6,*) ' *** POTIN9 CALLED WITHOUT  A SUITABLE USER-SUPPLIED',
     1  '  ROUTINE'
      STOP
      END 
      SUBROUTINE GAUSHP(NN,X,A)
C     CALCULATES THE ZEROS, X(I), AND WEIGHTS, A(I), I=1,NN, FOR
C       GAUSS-HERMITE QUADRATURE.
C     Approximates the integral from -infinity to infinity f(x)*exp(-x**2)
C       by the sum(i=1,nn) w(i)*f(x(i)).
C     ADAPTED BY S. GREEN FROM STROUD AND SECREST GAUSSIAN QUADRATURE FORMULAS.
C       VERSION OF 18 APRIL 94; FIXED NN=1 BUG 10 MAR 95 (SG)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER (MXIT=15)
      DIMENSION X(NN),A(NN)
      DATA EPS/1.D-15/
C
      GAM(Y)=(((((((.035868343D0*Y-.193527818D0)*Y+.482199394D0)*Y-
     1         .756704078D0)*Y+.918206857D0)*Y-.897056937D0)*Y+
     2             .988205891D0)*Y-.577191652D0)*Y+1.D0
C
      IF (NN.LE.0) THEN
        WRITE(6,*) ' *** GAUSHP CALLED FOR ILLEGAL NPT=',NN
        STOP
      ELSEIF (NN.EQ.1) THEN
        WRITE(6,*) ' *** GAUSHP. WARNING, SINGLE POINT REQUESTED.'
        X(1)=0.D0
        A(1)=SQRT(ACOS(-1.D0))
        RETURN
      ELSE
        FN=NN
        N1=NN-1
        N2=(NN+1)/2
C       COMPUTE GAMMA FN BY HASTINGS APPROX; 0.LE.X.LE.70.
        Z=FN
        IF (Z.LE.0.D0 .OR. Z.GE.7.D1) THEN
          WRITE(6,600) Z
  600     FORMAT('  *** GAUSHP. CANNOT GET GAMMA FUNCTION FOR',F10.2)
          STOP
        ENDIF
        IF (Z.EQ.1.D0) THEN
          GAMMA=1.D0
          GO TO 20
        ELSEIF (Z.LT.1.D0) THEN
          GAMMA=GAM(Z)/Z
          GO TO 20
        ELSE
          ZA=1.D0
   10     Z=Z-1.D0
          IF (Z-1.D0) 13,11,12
   11     GAMMA=ZA
          GO TO 20
   12     ZA=ZA*Z
          GO TO 10
   13     GAMMA=ZA*GAM(Z)
          GO TO 20
        ENDIF
   20   CC=1.7724538509D0*GAMMA*(2.D0**(-N1))
        S=(2.D0*FN+1.D0)**(1.D0/6.D0)
        DO 100 I=1,N2
        IF (I.EQ.1) THEN
C         LARGEST ZERO
          XT=S**3-1.85575D0/S
          GO TO 50
        ELSEIF (I.EQ.2) THEN
C         SECOND ZERO
          XT=XT-1.14D0*FN**.426D0/XT
          GO TO 50
        ELSEIF (I.EQ.3) THEN
C         THIRD ZERO
          XT=1.86D0*XT-0.86D0*X(1)
          GO TO 50
        ELSEIF (I.EQ.4) THEN
C         FOURTH ZERO
          XT=1.91D0*XT-0.91D0*X(2)
          GO TO 50
        ELSE
C         ALL HIGHER ZERO'S
          XT=2.D0*XT-X(I-2)
        ENDIF
C
C       IMPROVE THE APPROXIMATE ROOT XT AND OBTAIN
C         DPN = DERIVATIVE OF H(N) AT XT;  PN1 = VALUE OF H(N-1) AT XT
   50   IT=0
   60   IT=IT+1
        IF (IT.GT.MXIT) THEN
          WRITE(6,*) ' *** GAUSHP FAILED TO CONVERGE. ITERATIONS ='
     1             ,MXIT
          STOP
        ENDIF
        CALL HRECUR(P,DP,PN1,XT,NN)
        D=P/DP
        XT=XT-D
        IF (ABS(D).GT.EPS) GO TO 60
        DPN=DP
        X(I)=XT
        A(I)=CC/(DPN*PN1)
        NI=NN-I+1
        X(NI)=-XT
  100   A(NI)=A(I)
      ENDIF
      RETURN
      END

      SUBROUTINE HERM(H,N,X)
C
C     SUBROUTINE TO GENERATE HERMITE POLYNOMIALS
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION H(N)
      P0=1.0D0
      H(1)=P0
      IF(N.LE.1) RETURN
      X2=X+X
      P1=X2
      H(2)=P1
      IF(N.LE.2) RETURN
      DO 100 K=3,N
      TEMP=X2*P1 - DBLE(K+K-4)*P0
      P0=P1
      P1=TEMP
      H(K)=P1
  100 CONTINUE
      RETURN
      END

      SUBROUTINE HRECUR(PN,DPN,PN1,X,NN)
C     SG: ADAPTED FROM STROUD AND SECREST, GAUSSIAN QUADRATURE FORMULAS  GREEN.
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      P1=1.D0
      P=X
      DP1=0.D0
      DP=1.D0
      DO 1 J=2,NN
      FJ=J
      FJ2=(FJ-1.D0)/2.D0
      Q=X*P-FJ2*P1
      DQ=X*DP+P-FJ2*DP1
      P1=P
      P=Q
      DP1=DP
 1    DP=DQ
      PN=P
      DPN=DP
      PN1=P1
      RETURN
      END

      FUNCTION YRR(L1,L2,L,CT1,CT2,DP)
C
C     BISPHERICAL HARMONIC ANGULAR FUNCTIONS FOR TWO DIATOMS
C     CT1, CT2 ARE COS(THETA-1) AND COS(THETA-2), AND
C          DP IS DELTA(PHI), I.E., PHI2-PHI1, IN RADIANS
C     CF. GREEN, JCP 62, 2271 (1975) APPENDIX.
C     N.B. P(L,M;X) THERE IS (2*PI)**-1/2 NORMALIZED P(L,M;X)
C          MOLSCAT PLM(L,M,CT) ROUTINE IS NORMALIZED ON CT, AND
C               PLM(L,0,1.D0)=SQRT((2L+1)/2) .
C          THUS, MUST MULT EACH PLM BY (2*PI)**-1/2
C
C     ODD  L1+L2+L  *NOT* ALLOWED; TRAPPED W/MESSAGE AND STOP
C
C     NEEDS ROUTINES THRJ(XJ1,XJ2,XJ3,XM1,XM2,XM3)
C                    PLM(L,M,COSTH)
C                    PARITY(J)
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      LOGICAL ODD
      DATA PI/3.14159 26535 89793 D0/
      ODD(I)=2*(I/2)-I.NE.0
C
      IF (ODD(L1+L2+L)) GO TO 9999
C
      XL1=L1
      XL2=L2
      XL=L
C     SQRT(4*PI) FROM Y(L,M,THETA=0), 2*PI FOR TWO PLM'S
      DEN=SQRT(4.D0*PI)*2.D0*PI
      FACT=((2.D0*XL+1.D0)/DEN)*PARITY(L1+L2)
      MTOP=MIN(L1,L2)
      M=0
      XM=0.D0
      SUM=THRJ(XL1,XL2,XL,0.D0,0.D0,0.D0)*PLM(L1,0,CT1)*PLM(L2,0,CT2)
 2000 M=M+1
      IF (M.GT.MTOP) GO TO 3000
      XM=XM+1.D0
      SUM=SUM+2.D0*PARITY(M)*THRJ(XL1,XL2,XL,XM,-XM,0.D0)*
     1             PLM(L1,M,CT1)*PLM(L2,M,CT2)*COS(XM*DP)
      GO TO 2000
 3000 YRR=FACT*SUM
      RETURN
 9999 WRITE(6,699) L1,L2,L
  699 FORMAT('0 YRR *** ERROR.  ODD ARGUMENTS NOT ALLOWED',3I5)
      STOP
      END


